@@ -16,14 +16,14 @@ class DebugToolbarTests(unittest.TestCase):
     def tearDown(self):
         del self.config
 
-    def _makeOne(self, request, panel_classes):
+    def _makeOne(self, request, panel_classes, global_panel_classes):
         from pyramid_debugtoolbar.toolbar import DebugToolbar
-        return DebugToolbar(request, panel_classes)
+        return DebugToolbar(request, panel_classes, global_panel_classes)
 
     def test_ctor_panel_is_up(self):
         request = Request.blank('/')
         request.environ['HTTP_COOKIE'] = 'pdtb_active="id"'
-        toolbar = self._makeOne(request, [DummyPanelWithContent])
+        toolbar = self._makeOne(request, [DummyPanelWithContent], [DummyPanelWithContent])
         self.assertEqual(len(toolbar.panels), 1)
         panel = toolbar.panels[0]
         self.assertEqual(panel.request, request)
@@ -32,7 +32,7 @@ class DebugToolbarTests(unittest.TestCase):
     def test_ctor_panel_has_content(self):
         request = Request.blank('/')
         request.environ['HTTP_COOKIE'] = 'pdtb_active="id"'
-        toolbar = self._makeOne(request, [DummyPanelWithContent])
+        toolbar = self._makeOne(request, [DummyPanelWithContent], [DummyPanelWithContent])
         self.assertEqual(len(toolbar.panels), 1)
         panel = toolbar.panels[0]
         self.assertEqual(panel.request, request)
@@ -42,41 +42,39 @@ class DebugToolbarTests(unittest.TestCase):
         response = Response()
         response.content_type = 'text/plain'
         request = Request.blank('/')
-        toolbar = self._makeOne(request, [DummyPanel])
-        toolbar.process_response(response)
+        toolbar = self._makeOne(request, [DummyPanel], [DummyPanel])
+        toolbar.process_response(request, response)
         self.assertTrue(response.processed)
 
-    def test_process_response_html(self):
-        from pyramid_debugtoolbar.utils import ROOT_ROUTE_NAME
+    def test_inject_html(self):
         from pyramid_debugtoolbar.utils import STATIC_PATH
         self.config.add_static_view('_debugtoolbar/static',
                                     STATIC_PATH)
-        self.config.add_route(ROOT_ROUTE_NAME, '/_debugtoolbar')
+        self.config.add_route('debugtoolbar', '/_debugtoolbar/*subpath')
         response = Response('<body></body>')
         response.content_type = 'text/html'
         request = Request.blank('/')
+        request.id = 'abc'
         request.registry = self.config.registry
-        toolbar = self._makeOne(request, [DummyPanel])
-        toolbar.process_response(response)
-        self.assertTrue(response.processed)
+        toolbar = self._makeOne(request, [DummyPanel], [DummyPanel])
+        toolbar.inject(request, response)
         self.assertTrue(bytes_('div id="pDebug"') in response.app_iter[0])
         self.assertEqual(response.content_length, len(response.app_iter[0]))
 
     def test_passing_of_button_style(self):
-        from pyramid_debugtoolbar.utils import ROOT_ROUTE_NAME
         from pyramid_debugtoolbar.utils import STATIC_PATH
         self.config.add_static_view('_debugtoolbar/static',
                                     STATIC_PATH)
-        self.config.add_route(ROOT_ROUTE_NAME, '/_debugtoolbar')
+        self.config.add_route('debugtoolbar', '/_debugtoolbar/*subpath')
         self.config.registry.settings['debugtoolbar.button_style'] = \
             'top:120px;zoom:50%'
         response = Response('<body></body>')
         response.content_type = 'text/html'
         request = Request.blank('/')
+        request.id = 'abc'
         request.registry = self.config.registry
-        toolbar = self._makeOne(request, [DummyPanel])
-        toolbar.process_response(response)
-        self.assertTrue(response.processed)
+        toolbar = self._makeOne(request, [DummyPanel], [DummyPanel])
+        toolbar.inject(request, response)
         self.assertTrue(bytes_('top:120px;zoom:50%') in response.app_iter[0])
 
 
@@ -141,6 +139,7 @@ class Test_toolbar_handler(unittest.TestCase):
         settings['mako.directories'] = []
         settings['debugtoolbar.exclude_prefixes'] = ['/excluded']
         self.config.add_route(ROOT_ROUTE_NAME, '/_debug_toolbar')
+        self.config.add_route('debugtoolbar', '/_debug_toolbar/*subpath')
         self.config.add_static_view('_debugtoolbar/static',
                                     STATIC_PATH)
         self.config.include('pyramid_mako')
@@ -156,11 +155,17 @@ class Test_toolbar_handler(unittest.TestCase):
         return handler
 
     def _callFUT(self, request, handler=None, _logger=None):
-        registry = self.config.registry
         from pyramid_debugtoolbar.toolbar import toolbar_tween_factory
+        from pyramid_debugtoolbar.views import ExceptionDebugView
+        registry = self.config.registry
         if handler is None:
             handler = self._makeHandler()
+        def invoke_subrequest(request):
+            request.registry = registry.parent_registry = registry
+            request.exc_history = registry.exc_history
+            return ExceptionDebugView(request).exception()
         handler = toolbar_tween_factory(handler, registry, _logger=_logger)
+        request.invoke_subrequest = invoke_subrequest
         return handler(request)
 
     def test_it_path_cannot_be_decoded(self):
@@ -172,6 +177,7 @@ class Test_toolbar_handler(unittest.TestCase):
     def test_it_startswith_root_path(self):
         request = Request.blank('/_debug_toolbar')
         request.remote_addr = '127.0.0.1'
+        request.registry = self.config.registry
         result = self._callFUT(request)
         self.assertFalse(hasattr(request, 'debug_toolbar'))
         self.assertTrue(result is self.response)
